@@ -29,7 +29,7 @@ class AKREGATOR_EXPORT ArticleHtmlWebEngineWriter : public QObject
 {
     Q_OBJECT
 public:
-    explicit ArticleHtmlWebEngineWriter(ArticleViewerWebEngine *view, QObject *parent = Q_NULLPTR);
+    explicit ArticleHtmlWebEngineWriter(ArticleViewerWebEngine *view, QObject *parent = nullptr);
     ~ArticleHtmlWebEngineWriter();
 
     void begin();
